@@ -12,7 +12,7 @@ justDoItDoE <- function (command)
     else messages.connection <- getRcmdr("messages.connection")
     result <- try(eval(parse(text = command),envir = .GlobalEnv))
     ## warnings only, if no error abort
-    if (!class(result)[1]=="try-error") Rcmdr:::checkWarnings(readLines(messages.connection))
+    if (!class(result)[1]=="try-error") checkWarnings(readLines(messages.connection))
     if (getRcmdr("RStudio")) 
         Sys.sleep(0)
      result
